@@ -16,7 +16,6 @@
  * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
-#include "helpers.h"
 #include "in_process_server.h"
 
 #include <gmock/gmock.h>
@@ -144,3 +143,26 @@ TEST_F(FrameSubmission, when_client_endlessly_requests_frame_then_callbacks_are_
 
     EXPECT_THAT(std::chrono::steady_clock::now(), Lt(timeout)) << "Timed out looping in frame callback storm";
 }
+
+/*
+ * The above test checks that frame callbacks are throttled, but not that
+ * they are sent at all.
+ *
+ * We also need to test that these type of buffer-less frame requests
+ * *do* get a callback, eventually.
+ */
+TEST_F(FrameSubmission, frame_requests_without_buffer_are_called_back_eventually)
+{
+    std::array<bool, 5> called{};
+
+    wlcs::Client client{the_server()};
+    auto surface = client.create_visible_surface(640, 480);
+
+    for (auto i = 0u; i < called.size(); ++i)
+    {
+        surface.add_frame_callback([&called, i](auto) { called[i] = true; });
+        wl_surface_commit(surface);
+    }
+
+    client.dispatch_until([&called]() { return std::all_of(called.begin(), called.end(), [](bool value) { return value; }); });
+}
